#
# spec file for package moe
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           moe
Version:        1.14
Release:        1.3
Summary:        A Text Editor
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://www.gnu.org/software/moe/moe.html
Source:         https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.lz
Source1:        https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.lz.sig
Source2:        http://savannah.gnu.org/people/viewgpg.php?user_id=12809#/%{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libstdc++-devel
BuildRequires:  lzip
BuildRequires:  make
BuildRequires:  ncurses-devel

%description
GNU Moe is an 8-bit clean, console text editor for ISO-8859 and ASCII
character encodings. It has a modeless interface, online help,
multiple windows, unlimited undo/redo capability, unlimited line length, global
search/replace (on all buffers at once), block operations, automatic
indentation, word wrapping, file name completion, directory browser, duplicate
removal from prompt histories, delimiter matching, text conversion from/to
UTF-8 and romanization.

%prep
%autosetup

%build
%configure
%make_build CXXFLAGS="%{optflags}"

%install
%make_install install-man

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%config(noreplace) %{_sysconfdir}/moe.conf
%{_bindir}/moe
%{_infodir}/moe.info%{?ext_info}
%{_mandir}/man1/moe.1%{?ext_man}

%changelog
* Mon Jan 22 2024 Andreas Stieger <andreas.stieger@gmx.de>
- GNU moe 1.14:
  * Multiple updates to text UI display and behavior
  * no longer processes backslash escapes in file names
  * Search supports '(D)elete' and '\=<ch>' (equivalence class)
  * Executable files (scripts) are now loaded with 'auto indent' on
  * commend 'b' scrolls backwards, like less
  * scroll keys work without Alt key in read-only buffers
  * Recursive load now ignores file names with extensions ".avi",
    ".docx", ".mp3", ".mp4", ".mpg", and man pages ".[0-9]".
  * The UTF-8 decoder now converts some box drawing characters.
* Tue Feb 28 2023 Andreas Stieger <andreas.stieger@gmx.de>
- GNU moe 1.13:
  * 'moerc' has been renamed to 'moe.conf', it is read form
    $XDG_CONFIG_HOME/moe.conf instead of $HOME/.moerc.
    (XDG_CONFIG_HOME defaults to $HOME/.config).
  * Multiple user interface fixes
  * Speed improvements,including start-up improvements
  * Some commands recognize additional inputsand options
  * Now accepts the escape sequences '\uhhhh' and '\Uhhhhhhhh'
    (universal-character-name) to either search or insert in the
    buffer the corresponding ISO 10646 character coded in UTF-8.
  * Now accepts the escape sequence '\dddd' (decimal code 'ddd')
    like GNU sed to either search or insert in the buffer the
    corresponding ISO-8859-15 character.
  * Recursive load now ignores file names with extensions
    ".lzma", ".pnm", ".tiff", ".zst", ".tzst".
* Tue Sep 13 2022 Martin Pluskal <mpluskal@suse.com>
- Use distribution CFLAGS
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.12
  * A '+' alone (without line number) before a file name in the
    command line puts the cursor at end-of-buffer.
  * In case of error in an argument to a command line option, moe
    now shows the name of the option as parsed from the command
    line.
  * The new command 'C-o b' (reformat paragraphs in block) has
    been added.
  * Moe now centers the cursor the first time each handle is
    displayed.
  * 'F2' (save) now can write an unnamed read-only buffer to a
    file without setting the buffer name.
  * 'undo' and 'redo' now show feedback ("undoing...",
    "redoing...").
  * The UTF-8 decoder now converts some more characters ('numero
    sign', 'arrow with tip', 'double arrow', 'Kelvin sign',
    'Angstrom sign').
* Tue Jan  5 2021 Andreas Stieger <andreas.stieger@gmx.de>
- GNU moe 1.11:
  * Begin of text is now correctly defined as the position of the
    first non-blank character in a line, instead of the first non-
    whitespace character. This fixes the behavior of 'auto indent'
    and 'smart home'.
  * Add new option '-2, --two-spaces', that tells moe to put two
    spaces after period when reformatting a paragraph, has been
    added.
  * Add new search sequence '\T' (trailing whitespace)
  * UTF-8 codes are now shown as Uhhhh, not 0xhhhh.
  * The command 'C-s g' (Show global status) now shows the number
    of buffers being edited, not the number of buffer handles.
  * Pressing <Tab> in the file menu now shows the list of matching
    files even if there is only one, showing that a matching file
    exists.
  * Add new command 'C-s b' (toggle clock blinking)
  * Recursive load now ignores some more non-text or non-source
    files by extension; ".bmp", ".elf", ".obj", ".xcf", ".zip",
    ".info", ".jpeg", ".class"
  * The command 'F3' (load file) now shows feedback
    ("loading...") and may be aborted with Control-C.
  * The command Control-X (save and close) now updates the status
    line before exiting if closing the last buffer handle.
  * The command Alt-Z (scroll down) now scrolls until only two
    lines are visible
  * The command 'C-k w' (write the block to a file) now asks
    before overwriting an existing file and works when writing
    from an unnamed read-only buffer.
  * The UTF-8 decoder now converts some more characters (mostly
    Greek) and some alphabetic presentation forms
  * It now also converts the 'latin capital letter sharp s
    (german)' to "SS".
  * The emergency save triggered by an abnormal event now only
    saves non-empty buffers and only once even if any of them has
    multiple handles.
  * The commands needed to set the text console in the right mode
    for moe have been documented in the manual.
* Fri Jan  4 2019 astieger@suse.com
- GNU moe 1.10:
  * The default right margin has been changed from 72 to 76.
  * The new command 'C-o k' (capitalize words in block) has been
    added. It uppercases the first letter of each word and
    lowercases the rest.
  * The new command 'C-s p' (show line position in buffer) has
    been added. It shows on the status line the percent position
    of the current line in the buffer.
  * Recursive load now ignores some non-text files by extension
  * Infinite replacement loops are now detected.
  * 'C-q c' (exit without saving) and 'C-q x' (save and exit) now
    exit much faster when editing many files (thousands).
  * 'C-q x' (save and exit) now does not delete any buffer handles
    until all modified buffers have been succesfully saved. And
    shows "Read only" without asking for a name if a modified
    unnamed read-only buffer is found.
  * The UTF-8 decoder now converts some more characters.
  * Showing the contents of a directory no longer alters the
    position of the top line of the buffers menu.
  * The buffers menu is now shown even if there is only one buffer
  * When showing the contents of a directory, ".." is now put
    always first even if some file precede it in ASCIIbetical order
  * On buffers larger than 1000 lines, bookmarks 1 to 9 are now set
    at 10%% to 90%% of the buffer size in lines
* Mon Mar 19 2018 jengelh@inai.de
- Ensure neutrality of description.
* Sun Mar 18 2018 avindra@opensuse.org
- GNU moe 1.9:
  * rc.cc: Load recursively all regular files in each directory
    passed in the command line.
  * Added a new help key 'C-a'.
  * encoding.cc: UTF-8 decoder now converts some more characters.
  * buffer_handle.h (Buffer_handle): Adjust '+line,col' for tabs.
  * set_to_matching_delimiter: Skip delimiters inside /**/ comments.
  * Added 'N' command to the basic less emulation.
  * rc.cc (process_options): Don't use stdin more than once.
  * window_vector.cc (remove_duplicate_lines): Run 20%% faster.
  * Cut long filenames in messages like "File '...filename' saved".
  * Set an 8-bit "C" locale in Cygwin to show chars > 127.
  * configure: Avoid warning on some shells when testing for g++.
  * Makefile.in: Detect the existence of install-info.
- cleanup with spec-cleaner
* Sun Jul 10 2016 mpluskal@suse.com
- Small spec file cleanup
* Sun Mar  6 2016 astieger@suse.com
- GNU moe 1.8:
  * Moe is now able to read some types of non regular files at
    startup. Opening non regular files during the editing session
    is not allowed because it could cause moe to be killed, losing
    the changes of any other files being edited.
  * "Center line" now works correctly in overwrite mode.
* Fri May  8 2015 astieger@suse.com
- GNU moe 1.7
- complete package overhaul
* Fri Sep  4 2009 pascal.bleser@opensuse.org
- update to 1.3
* Mon Feb 23 2009 guru@unixtech.be
- moved to openSUSE Build Service
- update to 1.1
* Wed Jan 17 2007 guru@unixtech.be
- new upstream version
* Fri Apr 21 2006 guru@unixtech.be
- new package
